ngff_zarr.to_ngff_zarr - ngff-zarr
Description: Module Contents: Functions:,,_pop_metadata_optionals,,,_prep_for_to_zarr,,, to_ngff_zarr, Write an image pixel array and metadata to a Zarr store with the OME-NGFF standard data model.,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.to_ngff_zarr`

## Module Contents

### Functions

`_pop_metadata_optionals` |
`_prep_for_to_zarr` |
`to_ngff_zarr` | Write an image pixel array and metadata to a Zarr store with the OME-NGFF standard data model.

### API

ngff_zarr.to_ngff_zarr._pop_metadata_optionals(metadata_dict)

ngff_zarr.to_ngff_zarr._prep_for_to_zarr(store: Union[collections.abc.MutableMapping, str, pathlib.Path, zarr.storage.BaseStore], arr: dask.array.Array) → dask.array.Array

ngff_zarr.to_ngff_zarr.to_ngff_zarr(store: Union[collections.abc.MutableMapping, str, pathlib.Path, zarr.storage.BaseStore], multiscales: ngff_zarr.multiscales.Multiscales, overwrite: bool = True, chunk_store: Optional[Union[collections.abc.MutableMapping, str, pathlib.Path, zarr.storage.BaseStore]] = None, progress: Optional[Union[ngff_zarr.rich_dask_progress.NgffProgress, ngff_zarr.rich_dask_progress.NgffProgressCallback]] = None, **kwargs) → None

  Write an image pixel array and metadata to a Zarr store with the OME-NGFF standard data model.

  Parameters:

    - store (MutableMapping, str or Path, zarr.storage.BaseStore) – Store or path to directory in file system.

    - multiscales (Multiscales) – Multiscales OME-NGFF image pixel data and metadata. Can be generated with ngff_zarr.to_multiscales.

    - overwrite (bool, optional) – If True, delete any pre-existing data in `store` before creating groups.

    - chunk_store (MutableMapping, str or Path, zarr.storage.BaseStore, optional) – Separate storage for chunks. If not provided, `store` will be used for storage of both chunks and metadata.

    - progress (RichDaskProgress) – Optional progress logger

    - **kwargs – Passed to the zarr.creation.create() function, e.g., compression options.